==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Image/ts/Image_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Image</name>
    <message>
        <location filename="../Image.js" line="+132"/>
        <source>Files</source>
        <translation>File</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>All Image Files (%1)</source>
        <translation>Tutti i file immagine (%1)</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All Files</source>
        <translation>Tutti i file</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Import Bitmap</source>
        <translation>Importazione bitmap</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../ImageInit.js" line="+2"/>
        <source>Insert Bitmap</source>
        <translation>Inserisci Bitmap</translation>
    </message>
    <message>
        <location filename="../Image.ui" line="+17"/>
        <source>Width:</source>
        <translation>Larghezza:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Keep proportions</source>
        <translation>Mantiene proporzioni</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Height:</source>
        <translation>Altezza:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Angle:</source>
        <translation>Angolo:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Image/ts/Image_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Image</name>
    <message>
        <location filename="../Image.js" line="+133"/>
        <source>Files</source>
        <translation>File</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>All Image Files (%1)</source>
        <translation>Tutti i file immagine (%1)</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All Files</source>
        <translation>Tutti i file</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Import Bitmap</source>
        <translation>Importazione bitmap</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../ImageInit.js" line="+2"/>
        <source>Insert Bitmap</source>
        <translation>Inserisci bitmap</translation>
    </message>
    <message>
        <location filename="../Image.ui" line="+17"/>
        <source>Width:</source>
        <translation>Larghezza:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Keep proportions</source>
        <translation>Mantiene proporzioni</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Height:</source>
        <translation>Altezza:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Angle:</source>
        <translation>Angolo:</translation>
    </message>
</context>
</TS>
